from flask import Flask, request
from .users import users
from ._defaults import Defaults

def auth(domain, prefix="", **kwArgs):
  auth_app = Flask('cognito_overlay')
  auth_app.config.from_object(Defaults)
  auth_app.config['CUSTOM_DOMAIN'] = domain
  for key in kwArgs:
    auth_app.config['CUSTOM_{}'.format(key.upper())] = kwArgs[key]

  auth_app.register_blueprint(users, url_prefix=prefix)

  return auth_app



from flask import Blueprint, request
import boto3
from ._config import CLIENT_ID

users = Blueprint('users', __name__)
_client = boto3.client('cognito-idp')

@users.route('/users', methods=['POST'])
def create_user():
  req_data = request.get_json()
  username = req_data.get('username', '')
  password = req_data.get('password', '')
  password_confirmation = req_data.get('password_confirmation', '')
  if not username:
    return 'Username is required', 400
  if not password:
    return 'Password is required', 400
  if not password_confirmation:
    return 'Password confirmation is required', 400
  if password != password_confirmation:
    return 'Password and Password confirmation do not match', 400
  
  result = _client.sign_up(
    ClientId=CLIENT_ID,
    Username=username,
    Password=password
  )

  # TODO: Recover from password errors and return friendly errors
  # TODO: Recover from duplicate users

  return result, 200

@users.route('/sessions', methods=['POST'])
def sign_in():
  req_data = request.get_json()
  username = req_data.get('username', '')
  password = req_data.get('password', '')

  result = _client.initiate_auth(
    AuthFlow='USER_PASSWORD_AUTH',
    AuthParameters={
      'USERNAME': username,
      'PASSWORD': password
    },
    ClientId=CLIENT_ID
  )
  # TODO: Handle not confirmed error

  if result:
    # TODO: Set cookie
    return '', 204

@users.route('/users/confirm', methods=['PUT'])
def confirm():
  req_data = request.get_json()
  username = req_data.get('username', '')
  confirmation_code = req_data.get('confirmation_code', '')

  result = _client.confirm_sign_up(
    ClientId=CLIENT_ID,
    Username=username,
    ConfirmationCode=confirmation_code
  )

  return '', 204


import os
import boto3
import json

_client = boto3.client('secretsmanager')
_secretname = os.getenv('AUTH_SECRET_ID')

record = _client.get_secret_value(SecretId=_secretname)
config = json.loads(record['SecretString'])

CLIENT_ID = config['client_id']